@@ -9,10 +9,11 @@ use Mojo::Server;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 has app => sub { Mojo::Server->new->build_app('Mojo::HelloWorld') };
 has [qw(auto_perform backend)];
+has clean_up_after => 2592000;
 has tasks => sub { {} };
 
 sub add_task {
@@ -199,6 +200,15 @@ L</"enqueue">, very useful for testing.
 Backend, usually a L<Minion::Backend::File> or L<Minion::Backend::Mango>
 object.
 
+=head2 clean_up_after
+
+  my $after = $minion->clean_up_after;
+  $minion   = $minion->clean_up_after(86400);
+
+Amount of time in seconds after which jobs that have reached the state
+C<finished> will be cleaned up automatically by L</"repair">, defaults to
+C<2592000>.
+
 =head2 tasks
 
   my $tasks = $minion->tasks;
